@@ -15,6 +15,7 @@ import types
 import typing
 from typing import Any, TypeVar, Union, Callable, Optional
 
+from .annotation import try_extract_type_notes
 from .eval_forward_refs import get_evaled_dataclass_fields
 from .dataclass_protocol import DataclassProtocol
 from .is_instance import get_container_type, is_instance
@@ -63,6 +64,7 @@ def pass_value(value: Any) -> Any:
 
 @functools.cache
 def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callable[[Any], Any]:
+    type_, _ = try_extract_type_notes(type_)
     type_origin = getattr(type_, '__origin__', None)
     type_args = getattr(type_, '__args__', None)
     if not type_origin and isinstance(type_, type):
@@ -164,6 +166,7 @@ def write_to_dict_or_raise(container: Optional[dict[str, Exception]], key: str,
 
 def convert_to_type(field_type: type[T], field_name: str, value: Any,
                     field_name_to_error: dict[str, Exception] = None) -> T:
+    field_type, _ = try_extract_type_notes(field_type)
     if dataclasses.is_dataclass(field_type):
         try:
             # noinspection PyTypeChecker
@@ -189,6 +192,7 @@ def convert(name: str, type_: type[T], init: bool, default: Any, default_factory
     if not init:
         return NoValue
 
+    type_, _ = try_extract_type_notes(type_)
     if value != NoValue:
         value = convert_to_type(type_, name, value, field_name_to_error)
     else:
@@ -210,6 +214,7 @@ def convert(name: str, type_: type[T], init: bool, default: Any, default_factory
 
 
 def dict_to_dataclass(dict_value: dict[str, Any], dataclass: type[DP]) -> DP:
+    dataclass, _ = try_extract_type_notes(dataclass)
     if not dataclasses.is_dataclass(dataclass):
         raise TypeError("expected dataclass type")
 
